import logging

from django.urls import reverse

from web.forms import WorkerForm
from web.models import Worker
from web.models.worker_study_role import WORKER_STAFF, ROLE_CHOICES_DOCTOR
from web.tests import create_worker
from web.tests.functions import create_language, create_location, create_availability
from .. import LoggedInTestCase

logger = logging.getLogger(__name__)


class WorkerViewTests(LoggedInTestCase):
    def test_render_workers_list_request(self):
        create_worker()

        response = self.client.get(reverse('web.views.workers'))
        self.assertEqual(response.status_code, 200)

    def test_render_add_worker_request(self):
        create_worker()

        response = self.client.get(reverse('web.views.worker_add', kwargs={'worker_type': WORKER_STAFF}))
        self.assertEqual(response.status_code, 200)

    def test_render_worker_added_request(self):

        language = create_language()
        location = create_location()
        count = Worker.objects.all().count()

        form = WorkerForm()
        form_data = {}
        for key, value in form.initial.items():
            if value is not None:
                form_data[key] = value
        form_data["first_name"] = "John"
        form_data["last_name"] = "Doe"
        form_data["phone_number"] = "0123456789"
        form_data["unit"] = "TEST DEPARTMENT"
        form_data["email"] = "john.doe@unknown.domain.com"
        form_data["specialization"] = "tester"
        form_data["languages"] = [language.id]
        form_data["locations"] = [location.id]
        form_data["role"] = ROLE_CHOICES_DOCTOR

        response = self.client.post(reverse('web.views.worker_add', kwargs={'worker_type': WORKER_STAFF}),
                                    data=form_data)

        self.assertEqual(response.status_code, 302)

        new_count = Worker.objects.all().count()
        self.assertEqual(count + 1, new_count)

    def test_render_edit_worker_request(self):
        worker = create_worker()

        response = self.client.get(reverse('web.views.worker_edit', args=[worker.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_add_availability_request(self):
        worker = create_worker()

        response = self.client.get(reverse('web.views.worker_availability_add', args=[worker.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_edit_availability_request(self):
        worker = create_worker()
        availability = create_availability(worker)

        response = self.client.get(reverse('web.views.worker_availability_edit', args=[availability.id]))
        self.assertEqual(response.status_code, 200)

    def test_render_add_holiday_request(self):
        worker = create_worker()

        response = self.client.get(reverse('web.views.worker_holiday_add', args=[worker.id]))
        self.assertEqual(response.status_code, 200)
